@@ -1,5 +1,7 @@
 #
 package Mail::Send;
+use strict;
+
 require Mail::Mailer;
 
 use Carp;
@@ -38,8 +40,6 @@ Mail::Send - Simple electronic mail interface
 
 =head1 DESCRIPTION
 
-$Revision: 1.3 $
-
 =head1 SEE ALSO
 
 Mail::Mailer
@@ -47,11 +47,14 @@ Mail::Mailer
 =head1 AUTHORS
 
 Tim Bunce <Tim.Bunce@ig.co.uk>, with a kick start from Graham Barr
-<bodg@tiuk.ti.com>. For support please contact comp.lang.perl.misc.
+<bodg@tiuk.ti.com>. With contributions by Gerard Hickey <hickey@ctron.com>
+For support please contact comp.lang.perl.misc.
 
 =cut
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
+use vars qw($VERSION);
+
+$VERSION = "1.04";
 sub Version { $VERSION }
 
 sub new {
@@ -83,10 +86,10 @@ sub delete {
     delete $me->{$hdr};
 }
 
-sub to		{ my $me=shift; $me->set('To', @_); }
-sub cc		{ my $me=shift; $me->set('Cc', @_); }
-sub bcc		{ my $me=shift; $me->set('Bcc', @_); }
-sub subject	{ my $me=shift; $me->set('Subject', @_); }
+sub to		{ my $me=shift; $me->set('To', join (',', @_)); }
+sub cc		{ my $me=shift; $me->set('Cc', join (',', @_)); }
+sub bcc		{ my $me=shift; $me->set('Bcc', join (',', @_)); }
+sub subject	{ my $me=shift; $me->set('Subject', join (' ', @_)); }
 
 
 sub open {
