@@ -5,10 +5,16 @@
 # modify it under the same terms as Perl itself.
 
 package Mail::Util;
+use strict;
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+use vars qw($VERSION @ISA @EXPORT_OK);
+
+$VERSION = "1.10";
 sub Version { $VERSION }
 
+=head1 NAME
+
+Mail::Util - mail utility functions
 
 =head1 SYNOPSIS
 
@@ -20,6 +26,36 @@ This package provides several mail related utility functions. Any function
 required must by explicitly listed on the use line to be exported into
 the calling package.
 
+=head2 read_mbox( $file )
+
+Read C<$file>, a binmail mailbox file, and return a list of  references.
+Each reference is a reference to an array containg one message.
+
+=head2 maildomain()
+
+Attempt to determine the current uers mail domain string via the following
+methods
+
+ Look for a sendmail.cf file and extract DH parameter
+ Look for a smail config file and usr the first host defined in hostname(s)
+ Try an SMTP connect (if Net::SMTP exists) first to mailhost then localhost
+ Use value from Net::Domain::domainname (if Net::Domain exists)
+
+=head2 mailaddress()
+
+Return a guess at the current users mail address. The user can force
+the return value by setting C<$ENV{MAILADDRESS}>
+
+=head1 AUTHOR
+
+Graham Barr <bodg@tiuk.ti.com>
+
+=head1 COPYRIGHT
+
+Copyright (c) 1995 Graham Barr. All rights reserved. This program is free
+software; you can redistribute it and/or modify it under the same terms
+as Perl itself.
+
 =cut
 
 require 5.000;
@@ -37,12 +73,6 @@ __END__
 
 sub read_mbox;
 
-=head2 read_mbox( $file )
-
-Read C<$file>, a binmail mailbox file, and return a list of Mail::Internet
-objects.
-
-=cut
 
 use FileHandle;
 require POSIX;
@@ -57,7 +87,7 @@ require POSIX;
  local $_;
 
  while(<$fd>) {
-  if($blank && /\AFrom /) {
+  if($blank && /\AFrom .*\d{4}/) {
    push(@mail, $mail) if scalar(@{$mail});
    $mail = [ $_ ];
    $blank = 0;
@@ -75,17 +105,6 @@ require POSIX;
  return wantarray ? @mail : \@mail;
 }
 
-=head2 maildomain()
-
-Attempt to determine the current uers mail domain string via the following
-methods
-
- Look for a sendmail.cf file and extract DH parameter
- Look for a smail config file and usr the first host defined in hostname(s)
- Try an SMTP connect (if Net::SMTP exists) first to mailhost then localhost
- Use value from Net::Domain::domainname (if Net::Domain exists)
-
-=cut
 
 sub maildomain {
 
@@ -163,12 +182,6 @@ sub maildomain {
  return $domain;
 }
 
-=head2 mailaddress()
-
-Return a guess at the current users mail address. The user can force
-the return value by setting C<$ENV{MAILADDRESS}>
-
-=cut
 
 sub mailaddress {
 
@@ -197,19 +210,5 @@ sub mailaddress {
  $mailaddress;
 }
 
-=head1 AUTHOR
 
-Graham Barr <bodg@tiuk.ti.com>
-
-=head1 COPYRIGHT
-
-Copyright (c) 1995 Graham Barr. All rights reserved. This program is free
-software; you can redistribute it and/or modify it under the same terms
-as Perl itself.
-
-=head1 REVISION
-
-$Revision: 1.8 $
-
-=cut
 
